1.14.6 — Rucio 1.2 documentation

# 1.14.6

## General

### Enhancements

- Clients: RSE distance APIs not exposed #330
- Core & Internals: support for multiple permission and schema policy #356
- Core & Internals: add # in cms regexp name #394
- Core & Internals: Configurable name length #399
- Core & Internals: Client: Check URL escaping code for handling of / #411
- Core & Internals: Include the network domain (wan, lan) in list_replicas #64
- Documentation: space-usage: Add documentation. #329
- Documentation: Contributing guide Improvement #331
- Infrastructure: Provide dev container that mounts code #322
- Release management: AUTHORS update #380
- Testing: propagate the rigth postgresql file in travis #359

### Bugs

- Core & Internals: get_submitted_at_rucio should return an array of submitted_at time stamps #232
- Core & Internals: redirect: wrong link follow format to metalink #348
- Core & Internals: PostgreSQL not working, 1 test failing #388
- Core & Internals: import rucio.core.rule fails with missing section #407
- Core & Internals: Move rule permission check is not working #426
- Core & Internals: database: bootstrap mismatch between SSH and GSS #439
- Infrastructure: Fix missing cx_Oracle dependency in DockerFile #317
- Life time model: Atropos doesn’t properly take into account computed eol_at #412
- Subscriptions: Change the set_new_dids method to set NULL value instead of 0 #447
- Testing: Database tests are not executed #383
- Transfers: Link_ranking based sorting in case of multipe tape replicas is done wrong #351

## Clients

### Enhancements

- Clients: Avoid session reuse when new token is needed #433
- Clients: Client-side escaping of generated URLs #436

## WebUI

### Enhancements

- WebUI: add suspicious files dump description to WebUI #363
- WebUI: Copyright statement of WebUI footer needs to be updated to include 2018 #430